instastalk
==========
Instastalk is a library driven by a master creep who develops massive crush to instagram celebrities and wishes to automate the process of downloading and backing up their photos.

Disclaimer
----------
This project was initiated as a python practice and I have no intention of going against any rules and regulations of Instagram. Be discrete.